=======
History
=======

0.5.0 (2018-10-02)
------------------

* added two new methods get_shop_attribute and set_shop_attribute to shop class
* fixed some documentation typos
* fixed some code comments
* updated dec requirements via pyup

0.4.0 (2018-09-10)
------------------

* update zeep to 3.1.0
* added coveralls to testsuite
* ShopAddress attributes to shop class
* update to ShopConfigService12, getAllInfo is now fixed

0.3.0 (2017-12-22)
------------------

* added "shop" class which is a pythonic wrapper over the shopconfigservice

0.2.1 (2017-12-19)
------------------

* fixed AddtionalAttributes and SecondaryDomains
* restructuring

0.2.0 (2017-12-08)
------------------

* First "working" release

0.1.2 through 0.1.7 (2017-12-08)
--------------------------------

* Travis deployment tests

0.1.0 (2017-12-05)
------------------

* First release on PyPI.
